<?php
defined('ABSPATH') or die();
/**
 * BeautyMatters Wordpress MetaBoxes
 * @author Emanuel Seibold (info@seiboldsoft.de)
 * @package WordPress
 * @subpackage BeautyMatters Theme
 */
add_action('save_post', 'custom_post_meta_box_save');
add_action('save_page', 'custom_post_meta_box_save');

function custom_post_meta_box_save($post_id) {


    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    if (!isset($_POST['meta_box_nonce']) || !wp_verify_nonce($_POST['meta_box_nonce'], 'custom_post_meta_box_nonce')) {
        return;
    }

    if (!current_user_can('edit_post'))
        return;

    $allowed = array(
        'a' => array(// on allow a tags
            'href' => array() // and those anchors can only have href attribute
        )
    );


    if (isset($_POST['featured_image_size']))
        update_post_meta($post_id, 'featured_image_size', esc_attr($_POST['featured_image_size']));


    if (isset($_POST['sidebar_meta_box_enabled']))
        update_post_meta($post_id, 'sidebar_meta_box_enabled', esc_attr($_POST['sidebar_meta_box_enabled']));

    if (isset($_POST['sidebar_meta_box_sidebar']))
        update_post_meta($post_id, 'sidebar_meta_box_sidebar', esc_attr($_POST['sidebar_meta_box_sidebar']));

    if (isset($_POST['sidebar_enabled']))
        update_post_meta($post_id, 'sidebar_enabled', esc_attr($_POST['sidebar_enabled']));
}

function custom_post_meta_box_cb($post) {
    $values = get_post_custom($post->ID);
    $selectedFeaturedImageSize = isset($values['featured_image_size']) ? ($values['featured_image_size'][0]) : "";


    $selectedShow = isset($values['sidebar_enabled']) ? ($values['sidebar_enabled'][0]) : "";
    $selectedEnabled = isset($values['sidebar_meta_box_enabled']) ? ($values['sidebar_meta_box_enabled'][0]) : "";
    $selectedSidebar = isset($values['sidebar_meta_box_sidebar']) ? ($values['sidebar_meta_box_sidebar'][0]) : "";
    global $wp_registered_sidebars;

    wp_nonce_field('custom_post_meta_box_nonce', 'meta_box_nonce');
    ?>

    <h4><?php _e("Customize your Sidebar",'beautymatters');?></h4>
    <p>
        <label for="sidebar_enabled"><?php _e("Show Sidebar?",'beautymatters');?></label>
        <select name="sidebar_enabled" id="sidebar_enabled">
            <option value="enabled" <?php selected($selectedShow, 'enabled'); ?>><?php _e("Enable",'beautymatters');?></option>
            <option value="disabled" <?php selected($selectedShow, 'disabled'); ?>><?php _e("Disable",'beautymatters');?></option>
        </select>
    </p>

    <p>
        <label for="sidebar_meta_box_enabled"><?php _e("Enable Custom Sidebar?",'beautymatters');?></label>
        <select name="sidebar_meta_box_enabled" id="sidebar_meta_box_enabled">
            <option value="enabled" <?php selected($selectedEnabled, 'enabled'); ?>><?php _e("Enable",'beautymatters');?></option>
            <option value="disabled" <?php selected($selectedEnabled, 'disabled'); ?>><?php _e("Disable",'beautymatters');?></option>
        </select>
    </p>

    <p id="meta-choose-sidebar">
        <label for="sidebar_meta_box_sidebar"><?php _e("Choose Sidebar",'beautymatters');?></label>
        <select name="sidebar_meta_box_sidebar" id="sidebar_meta_box_sidebar">
            <?php
            foreach ($wp_registered_sidebars as $sidebar) :
                ?>
                <option value="<?php echo $sidebar['id']; ?>" <?php selected($selectedSidebar, $sidebar['id']); ?>><?php echo $sidebar['name']; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>


    <hr />
    <p>
        <label for="featured_image_size">Featured Image Size?</label>
        <select name="featured_image_size" id="featured_image_size">
            <option value="default" <?php selected($selectedFeaturedImageSize, 'default'); ?>><?php _e("Default",'beautymatters');?></option>
            <option value="none" <?php selected($selectedFeaturedImageSize, 'none'); ?>><?php _e("None",'beautymatters');?></option>
            <option value="1" <?php selected($selectedFeaturedImageSize, '1'); ?>><?php _e("Thumbnail",'beautymatters');?></option>
            <option value="2" <?php selected($selectedFeaturedImageSize, '2'); ?>><?php _e("Medium",'beautymatters');?></option>
            <option value="3" <?php selected($selectedFeaturedImageSize, '3'); ?>><?php _e("Large",'beautymatters');?></option>

        </select>
    </p>


    <?php
}

add_meta_box('custom-post-meta-box', 'BeautyMatters Options', 'custom_post_meta_box_cb', 'page', 'normal', 'high');
add_meta_box('custom-post-meta-box', 'BeautyMatters Options', 'custom_post_meta_box_cb', 'post', 'normal', 'high');
