<?php
defined('ABSPATH') or die();
/*
 * WordPress Instagram Widgets
 * author: Emanuel Seibold
 * version: 2016.01.01
 * license: MIT
 */


add_action('widgets_init', function() {
    register_widget('Last_Post_Extended_Widget');
});

/**
 * Adds My_Widget widget.
 */
class Last_Post_Extended_Widget extends WP_Widget {

    /**
     * Register widget with WordPress.
     */
    function __construct() {
        parent::__construct(
                'Last_Post_Extended_Widget', // Base ID
                __('BeautyMatters - Recent Posts Extended', 'beautymatters'), // Name
                array('description' => __('Recent Posts Extended Widget', 'beautymatters'),) // Args
        );
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget($args, $instance) {

        echo '<div class="widget">';
        if (!empty($instance['title'])) {
            echo $args['before_title'] . apply_filters('widget_title', $instance['title']) . $args['after_title'];
        }

        $show_current_category = (isset($instance['show_current_category']) && $instance['show_current_category'] == 'on') ? 'true' : 'false';
        $number_of_posts = isset($instance['number_of_posts']) ? $instance['number_of_posts'] : '10';

        $category_id = '';

        if ($show_current_category == 'true') {
            $categories = get_the_category();
            $category_id = $categories[0]->cat_ID;
        }
        $args = array(
            'posts_per_page' => $number_of_posts,
            'offset' => 0,
            'category' => $category_id,
            'category_name' => '',
            'orderby' => 'date',
            'order' => 'DESC',
            'include' => '',
            'exclude' => '',
            'meta_key' => '',
            'meta_value' => '',
            'post_type' => 'post',
            'post_mime_type' => '',
            'post_parent' => '',
            'author' => '',
            'post_status' => 'publish',
            'suppress_filters' => true
        );
        $posts_array = get_posts($args);


        echo '<ul>';
        foreach ($posts_array as $post) {
            echo '<li><a href="' . esc_url(get_permalink($post->ID)) . '">' . $post->post_title . '</a></li>';
        }
        echo '</ul>';
        echo '</div>';
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form($instance) {
        $title = (isset($instance['title'])) ? $instance['title'] : __('Last Posts', 'beautymatters');
        $number_of_posts = (isset($instance['number_of_posts'])) ? $instance['number_of_posts'] : "10";
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title');
        ?>"><?php _e('Title:','beautymatters'); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('number_of_posts');
        ?>"><?php _e('Number of Posts:', 'beautymatters'); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id('number_of_posts'); ?>" name="<?php echo $this->get_field_name('number_of_posts'); ?>" type="text" value="<?php echo esc_attr($number_of_posts); ?>">
        </p>
        <p>
            <input class="checkbox" type="checkbox" <?php checked($instance['show_current_category'], 'on'); ?> id="<?php echo $this->get_field_id('show_current_category'); ?>" name="<?php echo $this->get_field_name('show_current_category'); ?>" /> 
            <label for="<?php echo $this->get_field_id('show_current_category'); ?>"><?php _e("Show only from current Category","beautymatters");?></label>
        </p>
        <?php
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update($new_instance, $old_instance) {
        $instance = $old_instance;

        $instance['title'] = (!empty($new_instance['title']) ) ? strip_tags($new_instance['title']) : '';
        $instance['number_of_posts'] = (!empty($new_instance['number_of_posts']) ) ? strip_tags($new_instance['number_of_posts']) : '10';
        $instance['show_current_category'] = (!empty($new_instance['show_current_category']) ) ? strip_tags($new_instance['show_current_category']) : 'off';


        return $instance;
    }

}
