<?php
defined('ABSPATH') or die();
/**
 * Default Page Header
 *
 * @author Emanuel Seibold (info@seiboldsoft.de)
 * @package WordPress
 * @subpackage BeautyMatters Theme
 */
?><!DOCTYPE html>
<!-- HTML5 -->
<html <?php language_attributes(); ?>>
    <head>
        <meta charset="<?php bloginfo('charset'); ?>">	
        <title><?php wp_title(); ?> </title>
        <?php do_action('wp_seo'); ?>
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <meta http-equiv="x-ua-compatible" content="ie=edge">
        <link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo('stylesheet_url'); ?>" />
        <link rel="stylesheet" type="text/css" media="all" href="<?php echo get_template_directory_uri(); ?>/assets/css/beautymatters.css" />
        <link rel="stylesheet" type="text/css" media="all" href="<?php echo get_template_directory_uri(); ?>/assets/css/animate.css" />
        <link rel="stylesheet" type="text/css" media="all" href="<?php echo get_template_directory_uri(); ?>/assets/css/font-awesome.min.css" />

        <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>" />
        <?php wp_head(); ?>
    </head>

    <body <?php body_class("custom-body"); ?> data-spy="scroll" data-target=".header-wrapper">

        <?php
        if (get_theme_mod("html-custom-body") != "") {
            echo get_theme_mod("html-custom-body");
        }
        ?>
        <div class="container<?php echo (get_theme_mod("layout-page-layout", "1") == "1") ? "-fluid" : ""; ?>">
            <div class="row">

                <a href="#content" class="sr-only"><?php _e("Skip to content", 'beautymatters'); ?></a>
                <!-- child of the body tag -->
                <span id="top-link-block" class="hidden">
                    <a href="#top" class="well well-sm"> 
                        <i class="glyphicon glyphicon-chevron-up"></i> Back to Top
                    </a>
                </span><!-- /top-link-block -->

                <header id="header-section" class="header-section">
                    <div class="top-header-bar">

                        <div class="container<?php echo (get_theme_mod("layout-page-layout") != "2") ? "" : "-fluid"; ?>">

                            <div class="row">
                                <div class="col-lg-6 col-xs-12 col-md-6 col-6">
                                    <?php echo get_theme_mod("header-top-text-left", __('<i class="fa fa-thumbs-up"></i> Best Service around <span class="divider-vertical"></span> <i class="fa fa-clock-o"></i> WORKING HOURS : MON-SAT (8.00AM - 6.00PM)', 'beautymatters')); ?>
                                </div>
                                <div class="col-lg-6 col-xs-12 col-md-6 col-6 text-right">
                                    <?php
                                    $socialMediaSettings = array(
                                        'Facebook' => array(
                                            'setting' => 'social-media-header-facebook-url',
                                            'icon' => 'fa-facebook',
                                        ),
                                        'Instagram' => array(
                                            'setting' => 'social-media-header-instagram-url',
                                            'icon' => 'fa-instagram'
                                        ),
                                        'Youtube' => array(
                                            'setting' => 'social-media-header-youtube-url',
                                            'icon' => 'fa-youtube'
                                        ),
                                        'Google Plus' => array(
                                            'setting' => 'social-media-header-google-plus-url',
                                            'icon' => 'fa-google-plus'
                                        ),
                                        'Twitter' => array(
                                            'setting' => 'social-media-header-twitter-url',
                                            'icon' => 'fa-twitter'
                                        )
                                    );

                                    foreach ($socialMediaSettings as $socialMediaSetting) {
                                        if (get_theme_mod($socialMediaSetting["setting"], "") != "") :
                                            ?>
                                            <a href="<?php echo get_option($socialMediaSetting["setting"], ""); ?>" target="_blank"><i class="fa <?php echo $socialMediaSetting["icon"]; ?>"></i></a>
                                            <?php
                                        endif;
                                    }
                                    ?>
                                </div>

                            </div>

                        </div>

                    </div>
                    <nav class="navbar navbar-default sliding-u-l-r-l">
                        <?php if (get_theme_mod("layout-page-layout") != "2") : ?>
                            <div class="container">
                            <?php endif; ?>
                            <div class="row">
                                <div class="col-md-12 col-12 col-xs-12">
                                    <div class="navbar-header">
                                        <a class="navbar-brand" href="<?php echo esc_url(site_url()); ?>" title="home">
                                            <?php if (get_header_image() != "") : ?>
                                                <img src="<?php echo( get_header_image() ); ?>" alt="<?php echo( get_bloginfo('title') ); ?>" />
                                            <?php endif; ?>
                                        </a>

                                        <?php if (get_theme_mod("header-title-visible", "") == "on") { ?>
                                            <a class="brand" href="<?php echo esc_url(site_url()); ?>" title="home"><h1><?php bloginfo('name'); ?></h1><small><?php bloginfo('description'); ?></small></a>
                                        <?php } ?>
                                    </div>




                                    <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target=".navbar-collapse" aria-expanded="false" aria-controls="header">
                                        <span class="sr-only">Toggle navigation</span>
                                        <i class="fa fa-bars"></i> Menu
                                    </button>
                                    <div id="navbar" class="navbar-collapse collapse pull-right">
                                        <!--main navigation-->
                                        <?php
                                        if (is_front_page()) {
                                            if (has_nav_menu('home-menu')) {
                                                wp_nav_menu(array(
                                                    'menu' => '',
                                                    'theme_location' => 'home-menu',
                                                    'depth' => 2,
                                                    'container' => false,
                                                    'menu_class' => 'nav navbar-nav',
                                                    'list_class' => 'sliding-middle-out',
                                                    'fallback_cb' => 'wp_page_menu',
                                                    'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>',
                                                    'walker' => new wp_bootstrap_navwalker())
                                                );
                                            } else {
                                                echo '<h3>Warning. Please assign a menu first</h3>';
                                                ?>
                                                <?php
                                            }
                                        } else {
                                            if (has_nav_menu('main-menu')) {

                                                wp_nav_menu(array(
                                                    'menu' => '',
                                                    'theme_location' => 'main-menu',
                                                    'depth' => 2,
                                                    'container' => false,
                                                    'menu_class' => 'nav navbar-nav',
                                                    'list_class' => 'sliding-middle-out',
                                                    'fallback_cb' => 'wp_page_menu',
                                                    'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>',
                                                    'walker' => new wp_bootstrap_navwalker())
                                                );
                                            }
                                        }
                                        ?>

                                        <?php
                                        $all_options = wp_load_alloptions();
                                        //var_dump($all_options);
                                        ?>


                                        <?php if (get_theme_mod("header-badge-visible", "on") == "on") { ?>
                                            <?php echo get_theme_mod("header-badge-text"); ?>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                            <?php if (get_theme_mod("layout-page-layout") != "2") : ?>
                            </div>
                        <?php endif; ?>
                    </nav>
                </header>


                <?php if (!is_front_page()) { ?>

                    <?php if (get_theme_mod("ads-below-header-728x90") != "") : ?>
                        <div class="row text-center content-header"><?php echo get_theme_mod("ads-below-header-728x90"); ?></div>                
                    <?php endif; ?>

                    <?php if (get_theme_mod("ads-below-header-728x15") != "") : ?>
                        <div class="row text-center content-header"><?php echo get_theme_mod("ads-below-header-728x15"); ?></div>                
                    <?php endif; ?>
                    <?php if (get_theme_mod("ads-below-header-dynamic-size") != "") : ?>
                        <div class="row text-center content-header"><?php echo get_theme_mod("ads-below-header-dynamic-size"); ?></div>                
                    <?php endif; ?>
                <?php } ?>
