<?php

/**
 * Plugin Name: Simple Amazon
 * Description: A simple Amazon-Plugin to extend wordpress with Amazon Products and convert all Links to affiliate Links.
 * Plugin URI: http://www.seiboldsoft.de
 * Author: Emanuel Seibold
 * Author URI: http://www.seiboldsoft.de
 * Version: 1.0
 * Text Domain: simple-amazon
 * License: GPL2

  Copyright 2016 Emanuel Seibold (email : wordpress AT seiboldsoft DOT de)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
/**
 * Define versions and pathes
 * 
 */
define('SSA_VERSION', '1.6');
define('SSA_PATH', dirname(__FILE__));
define('SSA_PATH_INCLUDES', dirname(__FILE__) . '/inc');
define('SSA_FOLDER', basename(SSA_PATH));
define('SSA_URL', plugins_url() . '/' . SSA_FOLDER);
define('SSA_URL_INCLUDES', SSA_URL . '/inc');
define('SSA_TEMPLATES', SSA_URL . '/templates');

/**
 * 
 * The plugin base class - the root of all WP goods!
 * 
 * @author Emanuel Seibold
 *
 */
class SSA_Plugin_Base {

    /**
     * 
     * Assign everything as a call from within the constructor
     */
    public function __construct() {

        add_action('wp_enqueue_scripts', array($this, 'ssa_add_JS'));
        add_action('wp_enqueue_scripts', array($this, 'ssa_add_CSS'));

        // add scripts and styles only available in admin
        add_action('admin_enqueue_scripts', array($this, 'ssa_add_admin_JS'));

        // Register activation and deactivation hooks
        register_activation_hook(__FILE__, 'ssa_on_activate_callback');
        register_deactivation_hook(__FILE__, 'ssa_on_deactivate_callback');

        // Translation-ready
        add_action('plugins_loaded', array($this, 'ssa_add_textdomain'));

        // Add earlier execution as it needs to occur before admin page display
        add_action('admin_init', array($this, 'ssa_register_settings'), 5);
        add_action('admin_init', array($this, 'ssa_tinymce_button_init'), 6);
        add_action('init', array($this, 'ssa_add_shortcode'));

        // register admin pages for the plugin
        add_action('admin_menu', array($this, 'ssa_admin_pages_callback'));
        add_action('admin_head', array($this, 'ssa_custom_admin_head'));

        /** adds the autoconvert filter * */
        if (get_option("ssa_setting")["ssa_opt_in_autoconvert"] == "on") {
            add_filter('the_content', array($this, 'filter_amazon_associate_filter'), 25);
            add_filter('comment_text', array($this, 'filter_amazon_associate_filter'), 25);
        }
    }

    public function simple_amazon_settings_page() {
        include_once( SSA_PATH . '/settings-page.php' );
    }

    public function ssa_admin_pages_callback() {
        add_submenu_page('options-general.php', __('Simple Amazon Settings', 'beautyamazon'), 'Simple Amazon', 'manage_options', 'simple_amazon_page', array($this, 'simple_amazon_settings_page'));
    }

    /**
     * 
     * Adding JavaScript scripts
     * 
     * Loading existing scripts from wp-includes or adding custom ones
     * 
     */
    public function ssa_add_JS() {

        wp_enqueue_script('jquery');
        // load custom JSes and put them in footer
        wp_register_script('simple-amazon-script', plugins_url('/js/simple-amazon.js', __FILE__), array('jquery'), '1.0', true);
        wp_enqueue_script('simple-amazon-script');
    }

    /**
     *
     * Adding JavaScript scripts for the admin pages only
     *
     * Loading existing scripts from wp-includes or adding custom ones
     *
     */
    public function ssa_add_admin_JS($hook) {

        wp_enqueue_script('jquery');
        wp_register_script('simple-amazon-admin', plugins_url('/js/simple-amazon-admin.js', __FILE__), array('jquery'), '1.0', true);
        wp_enqueue_script('simple-amazon-admin');
    }

    public function ssa_custom_admin_head() {
        global $ssa_helper;

        echo '<script>var simple_amazon_templates= [ ';
        foreach ($ssa_helper->show_templates("", false) as $item) {
            echo "{text: '" . esc_html($item) . "', value: '" . esc_html($item) . "'},";
        }
        echo '];</script>';
    }

    function filter_amazon_associate_filter($content) {

        $affiliate_code = (get_option("ssa_setting")["ssa_affiliateid_text"] != "") ? get_option("ssa_setting")["ssa_affiliateid_text"] : "seibo-21";

        return preg_replace(
                '/http:\/\/[^>]*?amazon.([^\/]*)\/([^>]*?ASIN|gp\/product|exec\/obidos\/tg\/detail\/-|[^>]*?dp)\/([0-9a-zA-Z]{10})[a-zA-Z0-9#\/\*\-\?\&#038;\%\=\,\._;]*/i', 'http://www.amazon.$1/exec/obidos/ASIN/$3/' . $affiliate_code, $content
        );
    }

    /**
     * 
     * Add CSS styles
     * 
     */
    public function ssa_add_CSS() {
        wp_register_style('simple-amazon-style', plugins_url('/css/simple-amazon.css', __FILE__), array(), '1.0', 'screen');
        wp_enqueue_style('simple-amazon-style');
    }

    /**
     * Initialize the Settings class
     * 
     * Register a settings section with a field for a secure WordPress admin option creation.
     * 
     */
    public function ssa_register_settings() {
        require_once( SSA_PATH . '/ssa-plugin-settings.class.php' );
        new SSA_Plugin_Settings();
    }

    /**
     * Register a sample shortcode to be used
     * 
     * First parameter is the shortcode name, would be used like: [simple-amazon]
     * 
     */
    public function ssa_add_shortcode() {
        add_shortcode('simple-amazon', array($this, 'ssa_amazon_shortcode_body'));
    }

    public function ssa_tinymce_button_init() {

        if (!current_user_can('edit_posts') && !current_user_can('edit_pages') && get_user_option('rich_editing') == 'true')
            return;
        add_filter("mce_external_plugins", array($this, 'ssa_amazon_register_tinymce_plugin'));
        add_filter('mce_buttons', array($this, 'ssa_amazon_add_tinymce_button'));
    }

    function ssa_amazon_register_tinymce_plugin($plugin_array) {
        $plugin_array['simple_amazon_button'] = plugins_url('/js/simple-amazon-admin.js', __FILE__);
        return $plugin_array;
    }

    function ssa_amazon_add_tinymce_button($buttons) {
        $buttons[] = "simple_amazon_button";
        return $buttons;
    }

    /**
     * Returns the content of the simple-amazon
     * @param array $attr arguments passed to array
     * @param string $content optional, could be used for a content to be wrapped
     */
    public function ssa_amazon_shortcode_body($attr, $content = null) {

        global $ssa_helper;
        $output = '';

        $pull_atts = shortcode_atts(array(
            'template' => '',
            'id' => 'id',
            'limit' => 'limit',
            'title' => 'Our Amazon Offers',
            'subtitle' => 'We have the best Amazon Offers',
            'extra_class' => '',
            'type' => 'product',
            'type_id' => '', //or asin
                ), $attr);


        if (isset($pull_atts['type_id']) && $pull_atts['type_id'] != '') {
            $ssa_helper->setAttr($pull_atts);

            if (isset($attr['template']) && $attr['template'] != "") {
                $ssa_helper->setTemplate(esc_html($attr["template"]));
            } else {
                $ssa_helper->setTemplate("default-responsive-product-simple");
            }
            $output .= $ssa_helper->generate_output();
        }


        return $output;
    }

    /**
     * Add textdomain for plugin
     */
    public function ssa_add_textdomain() {
        load_plugin_textdomain('simple-amazon', false, dirname(plugin_basename(__FILE__)) . '/lang/');
    }

}

/**
 * Register activation hook
 *
 */
function ssa_on_activate_callback() {
    // do something on activation
}

/**
 * Register deactivation hook
 *
 */
function ssa_on_deactivate_callback() {
    // do something when deactivated
}

require(SSA_PATH_INCLUDES . '/aws_signed_request.php');
require(SSA_PATH_INCLUDES . '/class-amazon-helper.php');
require(SSA_PATH_INCLUDES . '/class-amazon-reviews.php');

// Initialize everything
$ssa_helper = new SSA_Helper();
$ssa_plugin_base = new SSA_Plugin_Base();
