<?php

/**
 * Plugin Name: Simple Amazon
 * Description: This Helper will extend the Plugin to process Templates and Amazon Requests
 * Plugin URI: http://www.seiboldsoft.de
 * Author: Emanuel Seibold
 * Author URI: http://www.seiboldsoft.de
 * Version: 1.0
 * Text Domain: simple-amazon
 * License: GPL2

  Copyright 2016 Emanuel Seibold (email : wordpress AT seiboldsoft DOT de)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
class SSA_Helper {

    protected $attr;
    protected $template;
    protected $_amazon_country_code;

    public function __construct() {
        $this->_amazon_country_code = get_option("ssa_setting")["ssa_countrycode_select"];
    }

    public function show_templates($start_slug = "", $echo = true) {
        $items = array();
        foreach (scandir(SSA_PATH . "/templates/") as $item) {
            if (preg_match("/.php/i", $item)) {
                if ($echo)
                    echo $item;
                $items[] = pathinfo($item, PATHINFO_FILENAME);
            }
        }
        return $items;
    }

    public function set($key, $value) {
        $this->values[$key] = $value;
    }

    public function generate_output() {
        if ($this->attr != '') {
            try {
                ob_start();
                if (isset($this->attr['type_id']) && $this->attr['type_id'] != '') {

                    $request = aws_signed_request(strtolower($this->_amazon_country_code), array("Operation" => "ItemLookup", "ItemId" => $this->attr['type_id'], "AssociateTag" => get_option("ssa_setting")["ssa_affiliateid_text"], "ResponseGroup" => "Large"), get_option("ssa_setting")["ssa_publickey_text"], get_option("ssa_setting")["ssa_privatekey_text"]);
                    $response = @file_get_contents($request);

                    if ($response === FALSE) {
                        echo 'Amazon Request failed';
                    } else {
                        $product_affiliate_url = sprintf($this->amazon_url[$this->_amazon_country_code], $this->attr['type_id'], get_option("ssa_setting")["ssa_affiliateid_text"]);
                        $country = $this->_amazon_country_code;
                        include(SSA_PATH . "/templates/" . $this->template . ".php");
                    }
                }
                $var = ob_get_contents();
                ob_get_clean();
                return preg_replace('/^\s+|\n|\r|\s+$/m', '', $var);
            } catch (Exception $ex) {
                return $ex->getMessage();
            }
        } else {
            return "attributes were null";
        }
    }

    protected $_amazon_valid_country_codes = array(
        'BR', 'CA', 'DE', 'FR', 'IN', 'JP', 'MX', 'UK', 'US', 'IT', 'ES', 'CN'
    );
    protected $amazon_url = array(
        'BR' => 'http://www.amazon.com.br/exec/obidos/ASIN/%s/%s',
        'CA' => 'http://www.amazon.ca/exec/obidos/ASIN/%s/%s',
        'DE' => 'http://www.amazon.de/exec/obidos/ASIN/%s/%s',
        'FR' => 'http://www.amazon.fr/exec/obidos/ASIN/%s/%s',
        'JP' => 'http://www.amazon.jp/exec/obidos/ASIN/%s/%s',
        'MX' => 'http://www.amazon.com.mx/exec/obidos/ASIN/%s/%s',
        'UK' => 'http://www.amazon.co.uk/exec/obidos/ASIN/%s/%s',
        'US' => 'http://www.amazon.com/exec/obidos/ASIN/%s/%s',
        'IN' => 'http://www.amazon.in/exec/obidos/ASIN/%s/%s',
        'IT' => 'http://www.amazon.it/exec/obidos/ASIN/%s/%s',
        'ES' => 'http://www.amazon.es/exec/obidos/ASIN/%s/%s',
        'CN' => 'http://www.amazon.cn/exec/obidos/ASIN/%s/%s',
    );

    public function getValidCountryCodes() {
        return $this->_amazon_valid_country_codes;
    }

    function getAttr() {
        return $this->attr;
    }

    function setAttr($attr) {
        $this->attr = $attr;
    }

    function getTemplate() {
        return $this->template;
    }

    function setTemplate($template) {
        $this->template = $template;
    }

    function get_amazon_country_code() {
        return $this->_amazon_country_code;
    }

    function set_amazon_country_code($_amazon_country_code) {
        $this->_amazon_country_code = $_amazon_country_code;
    }

}
