<?php

class SSA_Plugin_Settings {

    private $ssa_setting;

    public function __construct() {
        $this->ssa_setting = get_option('ssa_setting', '');
        add_action('admin_init', array($this, 'register_settings'));
    }

    /**
     * Setup the settings
     * 
     * Add a single checkbox setting for Active/Inactive and a text field 
     * just for the sake of our demo
     * 
     */
    public function register_settings() {
        register_setting('ssa_setting', 'ssa_setting', array($this, 'ssa_validate_settings'));

        add_settings_section(
                'ssa_settings_section', // ID used to identify this section and with which to register options
                __("Settings", 'simple-amazon'), // Title to be displayed on the administration page
                array($this, 'ssa_settings_callback'), // Callback used to render the description of the section
                'ssa-plugin-base'                           // Page on which to add this section of options
        );

        add_settings_field(
                'ssa_opt_in_autoconvert', // ID used to identify the field throughout the theme
                __("Convert all URLs to your Affiliate ID:", 'simple-amazon'), // The label to the left of the option interface element
                array($this, 'ssa_opt_in_autoconvert_callback'), // The name of the function responsible for rendering the option interface
                'ssa-plugin-base', // The page on which this option will be displayed
                'ssa_settings_section'         // The name of the section to which this field belongs
        );

        add_settings_field(
                'ssa_affiliateid_text', // ID used to identify the field throughout the theme
                __("Affiliate ID:", 'simple-amazon'), // The label to the left of the option interface element
                array($this, 'ssa_affiliateid_text_callback'), // The name of the function responsible for rendering the option interface
                'ssa-plugin-base', // The page on which this option will be displayed
                'ssa_settings_section'         // The name of the section to which this field belongs
        );

        add_settings_field(
                'ssa_publickey_text', // ID used to identify the field throughout the theme
                __("Public Key:", 'simple-amazon'), // The label to the left of the option interface element
                array($this, 'ssa_publickey_text_callback'), // The name of the function responsible for rendering the option interface
                'ssa-plugin-base', // The page on which this option will be displayed
                'ssa_settings_section'         // The name of the section to which this field belongs
        );

        add_settings_field(
                'ssa_privatekey_text', // ID used to identify the field throughout the theme
                __("Private Key:", 'simple-amazon'), // The label to the left of the option interface element
                array($this, 'ssa_privatekey_text_callback'), // The name of the function responsible for rendering the option interface
                'ssa-plugin-base', // The page on which this option will be displayed
                'ssa_settings_section'         // The name of the section to which this field belongs
        );

        add_settings_field(
                'ssa_countrycode_select', // ID used to identify the field throughout the theme
                __("Country Code:", 'simple-amazon'), // The label to the left of the option interface element
                array($this, 'ssa_countrycode_select_callback'), // The name of the function responsible for rendering the option interface
                'ssa-plugin-base', // The page on which this option will be displayed
                'ssa_settings_section'         // The name of the section to which this field belongs
        );
    }

    public function ssa_settings_callback() {
        printf(__("You can request an Affiliate ID and Keys at <a href='%s'>Partnernet</a>", 'simple-amazon'), 'https://partnernet.amazon.de/gp/associates/join/landing/main.html');
    }

    public function ssa_opt_in_autoconvert_callback() {
        $enabled = false;
        $out = '';
        $val = false;

        // check if checkbox is checked
        if (!empty($this->ssa_setting) && isset($this->ssa_setting['ssa_opt_in_autoconvert'])) {
            $val = true;
        }

        if ($val) {
            $out = '<input type="checkbox" id="ssa_opt_in_autoconvert" name="ssa_setting[ssa_opt_in_autoconvert]" CHECKED  />';
        } else {
            $out = '<input type="checkbox" id="ssa_opt_in_autoconvert" name="ssa_setting[ssa_opt_in_autoconvert]" />';
        }

        echo $out;
    }

    public function ssa_publickey_text_callback() {
        echo $this->ssa_text_callback("ssa_publickey_text", "AKIAIPY5T23CWFXQJTCA");
    }

    public function ssa_privatekey_text_callback() {
        echo $this->ssa_text_callback("ssa_privatekey_text", "0PpTkd40ZL+f1Pqa9jIr53jZ0nfyx78CyvA8VhsQ");
    }

    public function ssa_affiliateid_text_callback() {
        echo $this->ssa_text_callback("ssa_affiliateid_text", "seibo-21");
    }

    function ssa_text_callback($id, $default = "") {
        $out = '';
        $val = '';

        if (!empty($this->ssa_setting) && isset($this->ssa_setting[$id]) && !empty($this->ssa_setting[$id])) {
            $val = $this->ssa_setting[$id];
        } else {
            $val = $default;
        }

        $out = '<input type="text" id="' . $id . '" name="ssa_setting[' . $id . ']" value="' . $val . '"  />';

        echo $out;
    }

    function ssa_countrycode_select_callback() {

        global $ssa_helper;

        $out = '';
        $val = '';


        if (!empty($this->ssa_setting) && isset($this->ssa_setting["ssa_countrycode_select"])) {
            $val = $this->ssa_setting["ssa_countrycode_select"];
        } else {
            $val = "DE";
        }

        $out .= '<select name="ssa_setting[ssa_countrycode_select]" id="ssa_setting[ssa_countrycode_select]">';

        foreach ($ssa_helper->getValidCountryCodes() as $ccodes) {

            if ($val == $ccodes) {
                $out .= '<option selected="selected"  value="' . $ccodes . '">' . $ccodes . '</option>';
            } else {
                $out .= '<option value="' . $ccodes . '">' . $ccodes . '</option>';
            }
        }
        $out .= '</select>';

        echo $out;
    }

    /**
     * Validate Settings
     * 
     * Filter the submitted data as per your request and return the array
     * 
     * @param array $input
     */
    public function ssa_validate_settings($input) {

        return $input;
    }

}
